scoretools.PerformerInventory
=============================

.. inheritance-diagram:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory
   :private-bases:

.. autoclass:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.inventory_name

   .. note:: Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

Methods
-------

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.append

   .. note:: Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.count

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.extend

   .. note:: Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.index

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.insert

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.pop

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.remove

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.reverse

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.sort

   .. note:: Inherited from `__builtin__.list`

Special Methods
---------------

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__add__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__contains__

   .. note:: Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__delitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__delslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__eq__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__ge__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__getitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__getslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__gt__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__iadd__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__imul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__iter__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__le__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__len__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__lt__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__mul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__ne__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__repr__

   .. note:: Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__reversed__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__rmul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__setitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__setslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__str__

   .. note:: Inherited from `__builtin__.object`
